==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fFload.h <==
// class soot.coffi.Instruction_Fload

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class c47aa5d43cbe4179 soot_coffi_Instruction__5fFload
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fFload_H_
#define _JC_soot_coffi_Instruction__5fFload_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fFload$sub_refs	_jc_soot_coffi_Instruction__5fFload$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fFload$sub_nonrefs	_jc_soot_coffi_Instruction__5fFload$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fFload$refs	_jc_soot_coffi_Instruction__5fFload$refs;
typedef struct _jc_soot_coffi_Instruction__5fFload$nonrefs	_jc_soot_coffi_Instruction__5fFload$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fFload$object	_jc_soot_coffi_Instruction__5fFload$object;

typedef const struct _jc_soot_coffi_Instruction__5fFload$vmethods	_jc_soot_coffi_Instruction__5fFload$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fFload$vtable	_jc_soot_coffi_Instruction__5fFload$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fFload$vtype	_jc_soot_coffi_Instruction__5fFload$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fFload$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fFload$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fFload$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fFload$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fFload$vmethods	soot_coffi_Instruction__5fFload;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fFload$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fFload$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fFload$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fFload$refs {
    _jc_soot_coffi_Instruction__5fFload$sub_refs	soot_coffi_Instruction__5fFload;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fFload$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fFload$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fFload$sub_nonrefs	soot_coffi_Instruction__5fFload;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fFload$object {
	_jc_soot_coffi_Instruction__5fFload$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fFload$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fFload$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fFload$vtype _jc_soot_coffi_Instruction__5fFload$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fFload, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fFload$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fFload_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fFload.h <==
// class soot.coffi.Instruction_Fload

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class c47aa5d43cbe4179 soot_coffi_Instruction__5fFload
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fFload_H_
#define _JC_soot_coffi_Instruction__5fFload_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fFload$sub_refs	_jc_soot_coffi_Instruction__5fFload$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fFload$sub_nonrefs	_jc_soot_coffi_Instruction__5fFload$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fFload$refs	_jc_soot_coffi_Instruction__5fFload$refs;
typedef struct _jc_soot_coffi_Instruction__5fFload$nonrefs	_jc_soot_coffi_Instruction__5fFload$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fFload$object	_jc_soot_coffi_Instruction__5fFload$object;

typedef const struct _jc_soot_coffi_Instruction__5fFload$vmethods	_jc_soot_coffi_Instruction__5fFload$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fFload$vtable	_jc_soot_coffi_Instruction__5fFload$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fFload$vtype	_jc_soot_coffi_Instruction__5fFload$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fFload$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fFload$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fFload$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fFload$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fFload$vmethods	soot_coffi_Instruction__5fFload;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fFload$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fFload$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fFload$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fFload$refs {
    _jc_soot_coffi_Instruction__5fFload$sub_refs	soot_coffi_Instruction__5fFload;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fFload$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fFload$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fFload$sub_nonrefs	soot_coffi_Instruction__5fFload;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fFload$object {
	_jc_soot_coffi_Instruction__5fFload$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fFload$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fFload$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fFload$vtype _jc_soot_coffi_Instruction__5fFload$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fFload, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fFload$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fFload_H_ */
